<template>
  <LoadingLayout :loading="isLoading">
    <PhoneBillRechargeBaseForm ref="formRef" v-model:form="form">
      <NutFormItem label="备注信息" class="bole-form-item" prop="remark">
        <NutInput
          v-model.trim="form.remark"
          class="bole-input-text"
          placeholder="请输入备注信息"
          type="text"
          max-length="30"
        />
      </NutFormItem>
      <div class="common-content">
        <NutButton class="recharge-button" type="primary" @click="handleSave">
          <div class="recharge-button-inner">
            <div class="recharge-button-text">保存</div>
          </div>
        </NutButton>
      </div>
    </PhoneBillRechargeBaseForm>
  </LoadingLayout>
</template>

<script setup lang="ts">
import PhoneBillRechargeBaseForm from '../PhoneBillRecharge/PhoneBillRechargeBaseForm.vue';
import { Button as NutButton } from '@nutui/nutui-taro';
import { reactive, ref, computed } from 'vue';
import {
  useLifeRechargeContext,
  LifeRechargeConstants,
  AddUpdateUserAccountInput,
} from '@life-payment/core-vue';
import { useAddUpdateUserAccount } from '../../hooks';
import LoadingLayout from '../../components//Layout/LoadingLayout.vue';
import { useQuery } from '@tanstack/vue-query';
import { PhoneUserAccountExtraProperties } from '../PhoneBillRecharge/context';

defineOptions({
  name: 'EditPhoneUserAccount',
});

type Props = {
  id?: string;
};

const props = withDefaults(defineProps<Props>(), {});

const emit = defineEmits<{
  (e: 'success'): void;
}>();

const { blLifeRecharge } = useLifeRechargeContext();

const { isLoading } = useQuery({
  queryKey: ['blLifeRecharge/getUserAccountDetail', props.id],
  queryFn: async () => {
    return await blLifeRecharge.services.getUserAccountDetail(
      { id: props.id },
      {
        showLoading: false,
      }
    );
  },
  onSuccess(data) {
    const currentUserAccountExtraProperties = JSON.parse(
      data.extraProperties
    ) as PhoneUserAccountExtraProperties;
    form.ispCode = currentUserAccountExtraProperties.ispCode;
    form.phone = data.content;
    form.name = currentUserAccountExtraProperties.name;
    form.remark = data.remark;
  },
  enabled: computed(() => !!props.id),
});

const form = reactive({
  ispCode: '',
  phone: '',
  name: '',
  remark: '',
});

const formRef = ref<any>(null);

function handleSave() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      handleAddUpdateUserAccount();
    }
  });
}

const { addUpdateUserAccount } = useAddUpdateUserAccount();

async function handleAddUpdateUserAccount() {
  try {
    let params: AddUpdateUserAccountInput = {
      userId: blLifeRecharge.accountModel.userId,
      operators: form.ispCode,
      lifePayType: LifeRechargeConstants.LifePayOrderTypeEnum.话费订单,
      content: form.phone,
      extraProperties: JSON.stringify(form),
      remark: form.remark,
      id: props.id,
    };
    await addUpdateUserAccount(params);
    emit('success');
  } catch (error) {}
}
</script>
